@@ -1,6 +1,6 @@
 from authorize import aim, arb
 import datetime
-from django.conf import settings
+from django.conf import settings as django_settings
 import fudge
 from fudge.inspector import arg
 import os
@@ -11,6 +11,7 @@ from ._utils import TestCase
 
 from .. import backends
 from .. import forms
+from .. import signals
 
 
 class AuthorizeNetBackendTestCase(TestCase):
@@ -61,9 +62,7 @@ class AuthorizeNetBackendTestCase(TestCase):
                 settings=settings)
         self.assertFalse(backend.testing)
 
-
     def test_adds_is_test_to_recurring_api_class_api_if_in_testing_mode(self):
-        settings = self.test_settings
         recurring_api_class = fudge.Fake().expects_call().with_args(arg.any(),
                 arg.any(), is_test=True)
 
@@ -73,7 +72,6 @@ class AuthorizeNetBackendTestCase(TestCase):
         fudge.verify()
 
     def test_is_test_is_false_for_recurring_api_class_api_by_default(self):
-        settings = self.test_settings
         recurring_api_class = fudge.Fake().expects_call().with_args(arg.any(),
                 arg.any(), is_test=False)
 
@@ -83,7 +81,6 @@ class AuthorizeNetBackendTestCase(TestCase):
         fudge.verify()
 
     def test_adds_is_test_to_api_class_api_if_in_testing_mode(self):
-        settings = self.test_settings
         api_class = fudge.Fake().expects_call().with_args(arg.any(), arg.any(),
                 delimiter=arg.any(), is_test=True)
 
@@ -104,7 +101,7 @@ class AuthorizeNetBackendTestCase(TestCase):
 
     def test_settings_defaults_to_django_settings(self):
         backend = backends.AuthorizeNetBackend()
-        self.assertEqual(backend.settings, settings)
+        self.assertEqual(backend.settings, django_settings)
 
     def test_settings_can_be_injected(self):
         r = random.randint(10000, 20000)
@@ -462,6 +459,25 @@ class AuthorizeNetBackendTestCase(TestCase):
         self.assertTrue("recurring_response" in result)
         self.assertEqual(result["recurring_response"], random_return)
 
+    def test_fires_donation_complete_on_successful_charge(self):
+        donation, form = self.random_donation_and_form
+        result = {
+            "status": True,
+            "random": random.randint(100, 200),
+        }
+        onetime_purchase = (fudge.Fake().is_callable()
+                .returns(result))
+
+        backend = backends.AuthorizeNetBackend()
+        signal = (fudge.Fake().expects_call()
+                .with_args(sender=backend, donation=donation,
+                        signal=arg.any(), form=form, result=result))
+        signals.successful_purchase.connect(signal)
+        with stub_onetime_purchase(backend, onetime_purchase):
+            backend.purchase(donation, form)
+
+        fudge.verify()
+        signals.successful_purchase.disconnect(signal)
 
 from contextlib import contextmanager
 
